@@ -108,6 +108,9 @@
 
 /* #define DEBUG_DNS_UPDATES */
 
+/* Define this if you want to debug the host part of the inform processing */
+/* #define DEBUG_INFORM_HOST */
+
 /* Define this if you want DHCP failover protocol support in the DHCP
    server. */
 
@@ -117,6 +120,10 @@
 
 #define NSUPDATE
 
+/* Define this if you want to enable the DHCP server attempting to
+   find a nameserver to use for DDNS updates. */
+#define DNS_ZONE_LOOKUP
+
 /* Define this if you want the dhcpd.pid file to go somewhere other than
    the default (which varies from system to system, but is usually either
    /etc or /var/run. */
@@ -228,16 +235,6 @@
 
 #define ACCEPT_LIST_IN_DOMAIN_NAME
 
-/* In RFC3315 section 17.2.2 stated that if the server was not going
-   to be able to assign any addresses to any IAs in a subsequent Request
-   from a client that the server should not include any IAs.  This
-   requirement was removed in an errata from August 2010.  Define the
-   following if you want the pre-errata version.  
-   You should only enable this option if you have clients that
-   require the original functionality. */
-
-/* #define RFC3315_PRE_ERRATA_2010_08 */
-
 /* In previous versions of the code when the server generates a NAK
    it doesn't attempt to determine if the configuration included a
    server ID for that client.  Defining this option causes the server
@@ -247,41 +244,23 @@
    host declarations.  With some configurations the server id
    computed for a NAK may not match that computed for an ACK. */
 
-/* #define SERVER_ID_FOR_NAK */
+#define SERVER_ID_FOR_NAK
 
-/* When processing a request do a simple check to compare the
-   server id the client sent with the one the server would send.
-   In order to minimize the complexity of the code the server
-   only checks for a server id option in the global and subnet
-   scopes.  Complicated configurations may result in differnet
-   server ids for this check and when the server id for a reply
-   packet is determined, which would prohibit the server from
-   responding.
+/* NOTE:  SERVER_ID_CHECK switch has been removed. Enabling server id
+ * checking is now done via the server-id-check statement. Please refer
+ * to the dhcpd manpage (server/dhcpd.conf.5) */
 
-   The primary use for this option is when a client broadcasts
-   a request but requires the response to come from one of the
-   failover peers.  An example of this would be when a client
-   reboots while its lease is still active - in this case both
-   servers will normally respond.  Most of the time the client
-   won't check the server id and can use either of the responses.
-   However if the client does check the server id it may reject
-   the response if it came from the wrong peer.  If the timing
-   is such that the "wrong" peer responds first most of the time
-   the client may not get an address for some time.
-
-   Currently this option is only available when failover is in
-   use.
-
-   Care should be taken before enabling this option. */
-
-/* #define SERVER_ID_CHECK */
-
-/* In the v6 server code log the addresses as they are assigned
-   to make it easier for an admin to see what has beend done.
-   This default to off to avoid changes to what is currently
-   logged. */
-
-/* #define LOG_V6_ADDRESSES */
+/* Include code to do a slow transition of DDNS records
+   from the interim to the standard version, or backwards.
+   The normal code will handle removing an old style record
+   when the name on a lease is being changed.  This adds code
+   to handle the case where the name isn't being changed but
+   the old record should be removed to allow a new record to
+   be added.  This is the slow transition as leases are only
+   updated as a client touches them.  A fast transition would
+   entail updating all the records at once, probably at start
+   up. */
+#define DDNS_UPDATE_SLOW_TRANSITION
 
 /* Define the default prefix length passed from the client to
    the script when modifying an IPv6 IA_NA or IA_TA address.
@@ -310,11 +289,26 @@
    this option will be removed at some time. */
 /* #define INCLUDE_OLD_DHCP_ISC_ERROR_CODES */
 
-/* Enable conversion at startup of leases from FTS_BACKUP to FTS_FREE
-   when either their pool has no configured failover peer or 
-   FAILOVER_PROTOCOL is not enabled.  This allows the leases to be
-   reclaimed by the server after a pool's configuration has changed
-   from failover to standalone. Prior to this such leases would remain
-   stuck in the backup state. */
-/* #define CONVERT_BACKUP_TO_FREE */
+/* Include definitions for various options.  In general these
+   should be left as is, but if you have already defined one
+   of these and prefer your definition you can comment the 
+   RFC define out to avoid conflicts */
+#define RFC2937_OPTIONS
+#define RFC4776_OPTIONS
+#define RFC4833_OPTIONS
+#define RFC4994_OPTIONS
+#define RFC5192_OPTIONS
+#define RFC5223_OPTIONS
+#define RFC5417_OPTIONS
+#define RFC5460_OPTIONS
+#define RFC5969_OPTIONS
+#define RFC5970_OPTIONS
+#define RFC5986_OPTIONS
+#define RFC6011_OPTIONS
+#define RFC6334_OPTIONS
+#define RFC6440_OPTIONS
+#define RFC6731_OPTIONS
+#define RFC6939_OPTIONS
+#define RFC6977_OPTIONS
+#define RFC7083_OPTIONS
 
